@@ -1330,7 +1330,7 @@ def http_request(
     #      _class_ = getattr(current_module, class_name)
     #
     # will raise an error as the specified class is not yet bounded to the
-    # the module.
+    # module.
 
     # Determine the name of the class of the method that is decorated, which
     # is a bit tricky as a function only becomes a method at runtime.  At
@@ -1350,11 +1350,11 @@ def http_request(
         if existing_http_method_spec:
             logger = get_logger()
             logger.error(f'Multiple handler declarations for endpoint "{http_method} {uri_pattern}":')
-            logger.error('- PRV: {}.{}.{}'.format(
+            logger.error('- Existing endpoint: {}.{}.{}'.format(
                 existing_http_method_spec.handler_module_name,
                 existing_http_method_spec.handler_class_name,
                 existing_http_method_spec.handler_method.__name__))
-            logger.error('- NEW: {}.{}.{}'.format(method.__module__, class_name, method.__name__))
+            logger.error('- New endpoint: {}.{}.{}'.format(method.__module__, class_name, method.__name__))
             raise Exception(f'The endpoint {http_method} {uri_pattern} is already registered')
 
         # Check coherence of the options passed to the decorator.
@@ -1518,15 +1518,15 @@ def get_request_application_id(request, signature_required):
     :return: identification of the RESTful API application the HTTP
         request is sent to.
     """
-    # When a RESTful API application is deployed on a development,
-    # integration, or test environment stage, the signature of a HTTP
-    # request is not absolutely required.
+    # When a RESTful API application is deployed on a development or an
+    # integration, the signature of an HTTP request is not absolutely
+    # required.
     if signature_required:
         environment_stage = getattr(settings, 'ENVIRONMENT_STAGE', EnvironmentStage.dev)
         signature_required = environment_stage not in (
             EnvironmentStage.dev,
-            EnvironmentStage.int,
-            EnvironmentStage.stg)
+            EnvironmentStage.int
+        )
 
     # When the signature of the HTTP request is required, check the presence
     # of the two HTTP headers `X-API-Key` and `X-API-Sig`, and check whether
@@ -1535,7 +1535,7 @@ def get_request_application_id(request, signature_required):
     #
     # @note: Authenticated HTTP request required HTTP signature, therefore
     #     checking the signature of a HTTP request has to be done before the
-    #     the authentication verification.
+    #     authentication verification.
     consumer_key = request.get_header('X-API-Key', data_type=HttpRequest.ArgumentDataType.hexadecimal)
     api_sig = request.get_header('X-API-Sig', is_required=signature_required)
 
