@@ -66,7 +66,8 @@ class BaseRdbmsService(BaseService):
                 settings.RDBMS_CONNECTION_PROPERTIES,
                 logger_name=settings.LOGGER_NAME,
                 auto_commit=auto_commit,
-                tag=self.get_service_name())
+                #tag=self.get_service_name()
+            )
 
     @staticmethod
     def sql_quote(value):
