@@ -282,7 +282,7 @@ class NotificationService(BaseRdbmsService):
                 'account_id': cast.string_to_uuid,
                 'app_id': cast.string_to_uuid,
                 'device_platform': DevicePlatform,
-                'locale': Locale,
+                'locale': cast.string_to_locale,
                 'object_status': ObjectStatus,
                 'registration_id': cast.string_to_uuid,
                 'update_time': cast.string_to_timestamp,
